package net.thecodersbreakfast.wickettips.presentation.wicket.enums.component.form;

import net.thecodersbreakfast.wickettips.presentation.wicket.enums.EnumMessageKeyProvider;

import org.apache.wicket.Component;
import org.apache.wicket.markup.html.form.ChoiceRenderer;
import org.apache.wicket.markup.html.form.IChoiceRenderer;


/**
 * Custom {@link ChoiceRenderer} displaying localized Enum values. <br/>
 * <br/>
 * The provided Component is used as the root of the I18N properties file search
 * process.
 * 
 * @author Olivier Croisier
 */
public class EnumChoiceRenderer<T extends Enum<T>> implements IChoiceRenderer<T> {
	// ================================================================================
	// Constructors
	// ================================================================================

	/** The Component used a the root of the I18N search process */
	private final Component resourceProvider;

	// ================================================================================
	// Constructors
	// ================================================================================

	/**
	 * Constructor
	 * 
	 * @param resourceProvider
	 *            The component to use as the root of the I18N search process
	 */
	public EnumChoiceRenderer(final Component resourceProvider) {
		this.resourceProvider = resourceProvider;
	}

	// ================================================================================
	// Overrides
	// ================================================================================

	@Override
	public Object getDisplayValue(final T value) {
		final String key = EnumMessageKeyProvider.getMessageKey(value);
		return resourceProvider.getString(key);
	}

	@Override
	public String getIdValue(final T object, final int index) {
		final Enum<?> enumValue = object;
		return enumValue.name();
	}

}
