package net.thecodersbreakfast.wickettips.presentation.wicket.enums.component.form;

import java.util.Arrays;
import java.util.List;

import org.apache.wicket.markup.html.form.DropDownChoice;
import org.apache.wicket.model.IModel;

/**
 * Custom DropDownChoice working automagically with Enums, showing localized
 * values of all the model's enum values. Best if used with a
 * {@link EnumChoiceRenderer} (the default if no other ChoiceRenderer is
 * provided) See {@link EnumChoiceRenderer} for the localization details.
 * 
 * @author Olivier Croisier
 */
public class EnumDropDownChoice<T extends Enum<T>> extends DropDownChoice<T> {

	// ================================================================================
	// Constructors
	// ================================================================================

	public EnumDropDownChoice(String id, IModel<T> model) {
		super(id);
		setModel(model);
		setChoiceRenderer(new EnumChoiceRenderer<T>(this));
	}

	public EnumDropDownChoice(String id, IModel<T> model, EnumChoiceRenderer<T> choiceRenderer) {
		super(id);
		setModel(model);
		setChoiceRenderer(choiceRenderer);
	}

	// ================================================================================
	// Overrides
	// ================================================================================

	@Override
	public List<? extends T> getChoices() {
		return Arrays.asList(getModelObject().getDeclaringClass().getEnumConstants());
	}
}
