package net.thecodersbreakfast.wickettips.presentation.wicket.enums.model;


import net.thecodersbreakfast.wickettips.presentation.wicket.enums.EnumMessageKeyProvider;

import org.apache.wicket.Component;
import org.apache.wicket.model.PropertyModel;
import org.apache.wicket.util.lang.PropertyResolver;


/**
 * PropertyModel that operates on an Enum and provides its internationalized
 * representation.
 * 
 * @author Olivier Croisier
 * @param <T>
 *            The model type
 */
public class EnumPropertyModel<T extends Enum<T>> extends PropertyModel<String> {

	// ================================================================================
	// Properties
	// ================================================================================
	private Component component;

	// ================================================================================
	// Constructors & Factory methods
	// ================================================================================
	public EnumPropertyModel(Object modelObject, String expression, Component resourceProvider) {
		super(modelObject, expression);
		this.component = resourceProvider;
	}

	// ================================================================================
	// Implementation of PropertyModel
	// ================================================================================
	@Override
	@SuppressWarnings("unchecked")
	public String getObject() {
		final String expression = propertyExpression();
		final Object target = getTarget();
		if (target != null) {
			T enumValue = (T) PropertyResolver.getValue(expression, target);
			String key = EnumMessageKeyProvider.getMessageKey(enumValue);
			return component.getString(key);
		}
		return null;
	}

}
